Crate pipewire_wrapper_proc_macro Copy item path Source interface Implement SpaInterface and
Proxied traits. object_type_impl Add an *Info and *Builder structures after the enum definition.
For each enum variant will be added optional struct fields with value and flags. proxy_wrapper Implement Wrapper trait for structure with the ref_: Proxy<'c> field.
Macros parameter will be used as target type to cast underlying proxy. spa_interface Implement SpaInterface RawWrapper Implement RawWrapper trait.
#[raw] attribute must be added before field with wrapped raw value. Wrapper Implement Wrapper trait.
#[raw_wrapper] attribute must be added before field with NonNull<impl RawWrapper> pointer to *Ref
struct, that implements RawWrapper